//
//  LocXViewController.m
//  LocX
//
//  Created by Michael Heyeck on 8/23/09.
//  Copyright Fair Oaks Labs, Inc. 2009. All rights reserved.
//

#import "LocXViewController.h"


@interface LocXViewController ()

- (void)launchLocationController;

@end


@implementation LocXViewController

@synthesize offSwitch;
@synthesize latitude;
@synthesize longitude;
@synthesize h_accuracy;
@synthesize altitude;
@synthesize v_accuracy;
@synthesize course;
@synthesize speed;
@synthesize updated;
@synthesize updated_suffix;


// The designated initializer. Override to perform setup that is required before the view is loaded.
- (id)initWithCoder:(NSCoder*)coder
{
    if (self = [super initWithCoder:coder])
	{
		formatter = [[NSDateFormatter alloc] init];
		formatter.AMSymbol = @"am";
		formatter.PMSymbol = @"pm";
		formatter.dateFormat = @"h:mm:ssa";
		
		[self launchLocationController];
    }
    return self;
}


/*
// The designated initializer. Override to perform setup that is required before the view is loaded.
- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
    if (self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil]) {
        // Custom initialization
    }
    return self;
}
*/

/*
// Implement loadView to create a view hierarchy programmatically, without using a nib.
- (void)loadView {
}
*/


/*
// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad {
    [super viewDidLoad];
}
*/


/*
// Override to allow orientations other than the default portrait orientation.
- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}
*/


- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning]; // Releases the view if it doesn't have a superview
    // Release anything that's not essential, such as cached data
}


- (IBAction)switchUpdates:(id)sender
{
	if (manager)
	{
		[manager stopUpdatingLocation];
		[manager release];
		manager = nil;
	}

	if ([sender isOn]) [self launchLocationController];
}


- (void)dealloc
{
	[manager release];
	[formatter release];
	[offSwitch release];

	[latitude release];
	[longitude release];
	[h_accuracy release];
	[altitude release];
	[v_accuracy release];
	[course release];
	[speed release];
	[updated release];
	[updated_suffix release];

	[super dealloc];
}

#pragma mark CLLocationManagerDelegate methods

- (void)locationManager:(CLLocationManager*)manager didFailWithError:(NSError*)error
{
	[offSwitch setOn:NO animated:YES];
}


- (void)locationManager:(CLLocationManager*)manager didUpdateToLocation:(CLLocation*)newLocation fromLocation:(CLLocation*)oldLocation
{
	if (newLocation.horizontalAccuracy < 0)
	{
		latitude.text	= @"N/A ";
		longitude.text	= @"N/A ";
		h_accuracy.text	= @"N/A ";
	}
	else
	{
		latitude.text	= [NSString stringWithFormat:@"%.6f",newLocation.coordinate.latitude];
		longitude.text	= [NSString stringWithFormat:@"%.6f",newLocation.coordinate.longitude];
		h_accuracy.text	= [NSString stringWithFormat:@"%d",(int) newLocation.horizontalAccuracy];
	}
	
	if (newLocation.verticalAccuracy < 0)
	{
		altitude.text	= @"N/A ";
		v_accuracy.text	= @"N/A ";
	}
	else
	{
		altitude.text	= [NSString stringWithFormat:@"%d",(int) newLocation.altitude];
		v_accuracy.text	= [NSString stringWithFormat:@"%d",(int) newLocation.verticalAccuracy];
	}
	
	course.text			= (newLocation.course<0)?@"N/A ":[NSString stringWithFormat:@"%d",(int) newLocation.course];
	speed.text			= (newLocation.speed<0)?@"N/A ":[NSString stringWithFormat:@"%d",(int) newLocation.speed];
	
	NSString* ts		= [formatter stringFromDate:newLocation.timestamp];
	updated.text		= [ts substringToIndex:[ts length]-2];
	updated_suffix.text	= [ts substringFromIndex:[ts length]-2];
}

#pragma mark Extension methods

- (void)launchLocationController
{
	manager = [[CLLocationManager alloc] init];
	manager.delegate = self;
	
	[manager startUpdatingLocation];
}

@end
